@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: about.c,v 1.13 2000/02/19 06:54:43 kahn Exp kahn $
+ * $Id: about.c,v 1.17 2000/03/29 04:19:22 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -21,6 +21,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include "main.h"
+#include "misc.h"
 #include "about.h"
 #ifdef USE_GNOME
 #include <gnome.h>
@@ -32,7 +33,6 @@
 #define APP_COPYRIGHT		"Copyright (C) 1998-2000"
 #define APP_AUTHOR_NAME		"Andy C. Kahn"
 
-
 /*** global function definitions ***/
 /*
  * PUBLIC: about_cb
@@ -43,40 +43,56 @@ void
 about_cb(GtkWidget *wgt, gpointer cbdata)
 {
 #ifdef USE_GNOME
+# ifdef USE_LIBGLADE
+	GladeXML *xml = my_glade_xml_get("About");
+	(void)my_glade_widget_get(xml, "About",
+				  GLADE_MODAL | GLADE_POS_MOUSE | GLADE_SHOW);
+	gtk_object_destroy(GTK_OBJECT(xml));
+# else
 	const char *authors[] = { APP_AUTHOR_NAME,
 				  NULL };
-	char *copyright;
-	copyright = g_new(char, strlen(APP_AUTHOR_NAME) + 32);
-	sprintf(copyright, "(C) 1998-2000 by %s", APP_AUTHOR_NAME);
-	gtk_widget_show(gnome_about_new(
-				(const char *)APP_NAME,
-				(const char *)APP_VERSION,
-				(const char *)copyright,
-				(const char **)authors,
-				(const char *)APP_URL,
-				(const char *)NULL));
+	char *copyright = NULL;
+	copyright = g_strdup_printf("(C) 1998-2000 by %s", APP_AUTHOR_NAME);
+	gtk_widget_show(gnome_about_new((const char *)APP_NAME,
+					(const char *)APP_VERSION,
+					(const char *)copyright,
+					(const char **)authors,
+					(const char *)APP_URL,
+					(const char *)NULL));
 	g_free(copyright);
+# endif
 #else
 	char *title, *msg;
-	int len;
 
+# ifdef GTK_HAVE_FEATURES_1_1_0
+	title = g_strdup_printf(" About %s ", APP_NAME);
+	msg = g_strdup_printf(" %s %s \n"	/* APP_NAME, APP_VERSION */
+			      " %s \n"		/* APP_URL */
+			      "\n"
+			      " %s \n"		/* APP_COPYRIGHT */
+			      " %s ",		/* APP_AUTHOR_NAME */
+			      APP_NAME, APP_VERSION,
+			      APP_URL,
+			      APP_COPYRIGHT,
+			      APP_AUTHOR_NAME);
+# else
+	int len;
 	title = g_new(char, strlen(APP_NAME) + 9);
 	g_snprintf(title, strlen(APP_NAME) + 9, " About %s ", APP_NAME);
 
 	len = strlen(APP_NAME) + strlen(APP_VERSION) + strlen(APP_URL) +
 	      strlen(APP_COPYRIGHT) + strlen(APP_AUTHOR_NAME) + 32;
 	msg = g_new(char, len);
-	g_snprintf(msg, len,
-		" %s %s \n"	/* APP_NAME, APP_VERSION */
-		" %s \n"	/* APP_URL */
-		"\n"
-		" %s \n"	/* APP_COPYRIGHT */
-		" %s ",		/* APP_AUTHOR_NAME */
-		APP_NAME, APP_VERSION,
-		APP_URL,
-		APP_COPYRIGHT,
-		APP_AUTHOR_NAME
-	);
+	g_snprintf(msg, len, " %s %s \n"	/* APP_NAME, APP_VERSION */
+			     " %s \n"		/* APP_URL */
+			     "\n"
+			     " %s \n"		/* APP_COPYRIGHT */
+			     " %s ",		/* APP_AUTHOR_NAME */
+			     APP_NAME, APP_VERSION,
+			     APP_URL,
+			     APP_COPYRIGHT,
+			     APP_AUTHOR_NAME);
+# endif
 
 	(void)do_dialog_ok(title, msg);
 	g_free(msg);
