@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: clipboard.c,v 1.6 1999/01/18 19:41:45 kahn Exp kahn $
+ * $Id: clipboard.c,v 1.11 2000/01/19 17:18:30 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -17,11 +17,12 @@
  *     along with this program; if not, write to the Free Software
  *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
-#include <gtk/gtk.h>
+#include "main.h"
+#ifdef USE_CLIPBOARD
 #include "doc.h"
 #include "msgbar.h"
 #include "clipboard.h"
+#include "gnpintl.h"
 
 
 /*** global function definitions ***/
@@ -37,14 +38,10 @@ copy_cb(GtkWidget *widget, gpointer cbdata)
 	doc_t *d;
 
 	g_assert(w != NULL);
-	d = doc_current(w);
+	d = DOC_CURRENT(w);
 	g_assert(d != NULL);
-#ifdef GTK_HAVE_FEATURES_1_1_0
 	gtk_editable_copy_clipboard(GTK_EDITABLE(d->data));
-#else
-	gtk_editable_copy_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
-#endif
-	msgbar_printf(w, "Text copied to clipboard...");
+	msgbar_printf(w, _("Text copied to clipboard..."));
 } /* copy_cb */
 
 
@@ -60,14 +57,10 @@ cut_cb(GtkWidget *widget, gpointer cbdata)
 	doc_t *d;
 
 	g_assert(w != NULL);
-	d = doc_current(w);
+	d = DOC_CURRENT(w);
 	g_assert(d != NULL);
-#ifdef GTK_HAVE_FEATURES_1_1_0
 	gtk_editable_cut_clipboard(GTK_EDITABLE(d->data));
-#else
-	gtk_editable_cut_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
-#endif
-	msgbar_printf(w, "Text cut to clipboard...");
+	msgbar_printf(w, _("Text cut to clipboard..."));
 } /* cut_cb */
 
 
@@ -83,14 +76,10 @@ paste_cb(GtkWidget *widget, gpointer cbdata)
 	doc_t *d;
 
 	g_assert(w != NULL);
-	d = doc_current(w);
+	d = DOC_CURRENT(w);
 	g_assert(d != NULL);
-#ifdef GTK_HAVE_FEATURES_1_1_0
 	gtk_editable_paste_clipboard(GTK_EDITABLE(d->data));
-#else
-	gtk_editable_paste_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
-#endif
-	msgbar_printf(w, "Text pasted from clipboard...");
+	msgbar_printf(w, _("Text pasted from clipboard..."));
 } /* paste_cb */
 
 
@@ -106,12 +95,13 @@ selall_cb(GtkWidget *widget, gpointer cbdata)
 	doc_t *d;
 
 	g_assert(w != NULL);
-	d = doc_current(w);
+	d = DOC_CURRENT(w);
 	g_assert(d != NULL);
 	gtk_editable_select_region(GTK_EDITABLE(d->data), 0,
 		gtk_text_get_length(GTK_TEXT(d->data)));
-	msgbar_printf(w, "All text selected...");
+	msgbar_printf(w, _("All text selected..."));
 } /* selall_cb */
 
+#endif	/* USE_CLIPBOARD */
 
 /* the end */
