@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: clipboard.h,v 1.3 1998/10/05 15:28:47 kahn Exp kahn $
+ * $Id: clipboard.h,v 1.5 1999/09/12 03:43:52 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#include "main.h"
+#ifdef USE_CLIPBOARD
 
 #include <gtk/gtk.h>
 
@@ -32,6 +34,7 @@ extern void copy_cb(GtkWidget *widget, gpointer cbdata);
 extern void paste_cb(GtkWidget *widget, gpointer cbdata);
 extern void selall_cb(GtkWidget *widget, gpointer cbdata);
 
+#endif	/* USE_CLIPBOARD */
 
 #ifdef __cplusplus
 }
