@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: file.c,v 1.44 2000/02/26 03:17:33 kahn Exp kahn $
+ * $Id: file.c,v 1.50 2000/03/31 04:39:14 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -57,6 +57,7 @@ static bool_t file_text_xmhtml_read(doc_t *d);
 
 
 /*** global function definitions ***/
+#ifndef USE_GNOME
 /*
  * PUBLIC: file_exist
  *
@@ -72,6 +73,7 @@ file_exist(char *fname)
 
 	return TRUE;
 } /* file_exist */
+#endif
 
 
 /*
@@ -106,7 +108,6 @@ char *
 file_full_pathname_make(char *fname)
 {
 	char *full, *cwd;
-	int len;
 
 	if (!fname)
 		return NULL;
@@ -120,12 +121,10 @@ file_full_pathname_make(char *fname)
 	if (cwd[strlen(cwd) - 1] == '/')
 		cwd[strlen(cwd) - 1] = '\0';
 
-	len = strlen(cwd) + strlen(fname) + 2;
-	full = g_new(char, len);
 	if ((strlen(fname) > 2) && fname[0] == '.' && fname[1] == '/')
-		g_snprintf(full, len, "%s/%s", cwd, fname + 2);
+		full = my_concat_dir_and_file(cwd, fname + 2);
 	else
-		g_snprintf(full, len, "%s/%s", cwd, fname);
+		full = my_concat_dir_and_file(cwd, fname);
 
 	/* use free() here, not g_free(), since getcwd() uses malloc() */
 	free(cwd);
@@ -152,7 +151,57 @@ file_get_stats(char *fname)
 } /* file_get_stats */
 
 
-#ifdef APP_GNP
+/*
+ * PUBLIC: file_open_fp
+ *
+ * common routine for opening a file and returning a FILE *.  If the fopen()
+ * fails, print an error message.  If successful, the file is locked and fp is
+ * returned.
+ */
+FILE *
+file_open_fp(const char *fname, const char *fmode, int flags,
+	     const char *funcname)
+{
+	FILE *fp;
+	char *buf, *errstr;
+#ifndef GTK_HAVE_FEATURES_1_1_0
+	int len;
+#endif
+
+	if ((fp = fopen(fname, fmode)) == NULL) {
+		errstr = g_strerror(errno);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+		buf = g_strdup_printf("%s: open failed ('%s', err=%d (%s))",
+				      funcname, fname, errno, errstr);
+#else
+		len = strlen(fname) + strlen(funcname) + strlen(errstr) + 64;
+		buf = g_new(char, len);
+		g_snprintf(buf, len, "%s: open failed ('%s', err=%d (%s))",
+			   funcname, fname, errno, errstr);
+#endif
+		msgbox_printf("%s\n", buf);
+		if (!(flags & OPEN_NO_ERROR))
+			(void)do_dialog_error(" Error opening file! ", buf);
+		g_free(buf);
+		return NULL;
+	}
+
+	if (!(flags & OPEN_NO_LOCK))
+		(void)file_lock(fname, fp, (flags & OPEN_EXCL), FALSE, TRUE);
+
+	return fp;
+} /* file_open_fp */
+
+
+void
+file_close_fp(const char *fname, FILE *fp)
+{
+	(void)fflush(fp);
+	(void)file_unlock(fname, fp);
+	(void)fclose(fp);
+} /* file_close_fp */
+
+
 /*
  * PUBLIC: file_open_execute
  *
@@ -205,7 +254,6 @@ out:
 
 	return 0;
 } /* file_open_execute */
-#endif	/* APP_GNP */
 
 
 /*
@@ -224,16 +272,9 @@ file_text_xmhtml_read(doc_t *d)
 #endif
 
 	/* open file */
-	if ((fp = fopen(d->fname, "r")) == NULL) {
-		char msg[255];
-
-		g_snprintf(msg, 255, "file_open_execute: could not open '%s'",
-			   d->fname);
-		perror(msg);
+	fp = file_open_fp(d->fname, "r", 0, "file_text_xmhtml_read");
+	if (fp == NULL)
 		return FALSE;
-	}
-	(void)file_lock(d->fname, fp, FALSE, FALSE, TRUE);
-
 
 	if (GTK_IS_TEXT(d->data))
 		gtk_text_freeze(GTK_TEXT(d->data));
@@ -278,8 +319,7 @@ file_text_xmhtml_read(doc_t *d)
 	/* buffer allocated, now actually read the file */
 	bytesread = 0;
 	while (bytesread < d->sb->st_size) {
-		/* flush any pending events */
-		gtk_main_iteration_do(FALSE);
+		gtk_events_flush();
 
 		num = fread(buf, 1, size, fp);
 		if (num > 0) {
@@ -306,8 +346,7 @@ file_text_xmhtml_read(doc_t *d)
 	} /* while more bytes to read */
 	g_free(buf);
 
-	(void)file_unlock(d->fname, fp);
-	(void)fclose(fp);
+	file_close_fp(d->fname, fp);
 	if (GTK_IS_TEXT(d->data))
 		gtk_text_thaw(GTK_TEXT(d->data));
 #ifdef USE_GTKXMHTML
@@ -412,20 +451,15 @@ file_save_execute(doc_t *d, bool_t saveas)
 		file_backup(d->fname);
 #endif	/* USE_BACKUP */
 
-	if ((fp = fopen(d->fname, "w")) == NULL) {
-		g_warning("file_save_execute: can't open '%s' for saving",
-			  d->fname);
+	fp = file_open_fp(d->fname, "w", OPEN_EXCL, "file_save_execute");
+	if (fp == NULL)
 		return FALSE;
-	}
-	(void)file_lock(d->fname, fp, TRUE, FALSE, TRUE);
 
 	/* try to set permissions to original. maybe use fchmod() and fchown? */
 	if (oldperm >= 0)
 		(void)chmod(d->fname, (mode_t)oldperm);
 	(void)chown((char *)d->fname, olduid, oldgid);
 
-	gtk_text_thaw(GTK_TEXT(d->data));
-
 	/*
 	 * this isn't very memory efficient; gtk_editable_get_chars()
 	 * (actually, it's gtk_text_get_chars()), returns the text in a newly
@@ -438,13 +472,11 @@ file_save_execute(doc_t *d, bool_t saveas)
 	if (fputs(buf, fp) == EOF) {
 		perror("Error saving file");
 		g_free(buf);
-		fclose(fp);
+		file_close_fp(d->fname, fp);
 		return FALSE;
 	}
 	g_free(buf);
-	(void)fflush(fp);
-	(void)file_unlock(d->fname, fp);
-	(void)fclose(fp);
+	file_close_fp(d->fname, fp);
 
 	gtk_label_set(GTK_LABEL(d->tablabel), doc_basefname(d));
 	d->changed = FALSE;
@@ -645,7 +677,9 @@ file_backup(char *fname)
 	char *backupname;
 	char *backupdir;
 	char *dname = NULL;
+#ifndef GTK_HAVE_FEATURES_1_1_0
 	int len;
+#endif
 
 	if (fname == NULL || !file_exist(fname))
 		return;
@@ -664,6 +698,11 @@ file_backup(char *fname)
 		}
 		backupdir = dname;
 	}
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	backupname = g_strdup_printf("%s/%s%s", backupdir, my_basename(fname),
+				     (prefs.backupsuffix) ?
+				     		prefs.backupsuffix : NULL);
+#else
 	len = 2 + strlen(backupdir) + strlen(my_basename(fname)) +
 	      (prefs.backupsuffix ? strlen(prefs.backupsuffix) : 1);
 	backupname = g_new(char, len);
@@ -671,6 +710,7 @@ file_backup(char *fname)
 	g_snprintf(backupname, len, "%s/%s%s",
 		   backupdir, my_basename(fname),
 		   (prefs.backupsuffix) ? prefs.backupsuffix : NULL);
+#endif
 	if (dname)
 		free(dname);	/* don't use g_free() */
 	GNPDBG_FILE(("file_backup: backup file = '%s'\n", backupname));
