@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: gtkefilesel.c,v 1.12 2000/02/21 18:32:18 kahn Exp kahn $
+ * $Id: gtkefilesel.c,v 1.13 2000/03/14 07:17:48 kahn Exp kahn $
  * 
  * GTK - The GIMP Toolkit
  * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
@@ -1558,7 +1558,7 @@ efilesel_populate(GtkEfileSel *fs, char *rel_path, int try_complete)
 								   width);
 				}
 			}
-			gtk_main_iteration_do(FALSE);
+			gtk_events_flush();
 		}
 		poss = cmpl_next_cmpl(cmpl_state);
 	}
