@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: menu.c,v 1.56 2000/02/28 17:22:37 kahn Exp kahn $
+ * $Id: menu.c,v 1.59 2000/04/14 02:44:57 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -4057,15 +4057,22 @@ menu_set_callback_data(win_t *w, GnomeUIInfo *menu)
 void
 menu_recent_doc_remove(gpointer data)
 {
+# ifndef GTK_HAVE_FEATURES_1_1_0
 	int len;
+# endif
 	char *menupath;
 	doc_new_name_t *dnnp = (doc_new_name_t *)data;
 
+# ifdef GTK_HAVE_FEATURES_1_1_0
+	menupath = g_strdup_printf("%s%s", MENU_PATH_RECENT_DOC,
+					   my_basename(dnnp->fname));
+# else
 	len = strlen(MENU_PATH_RECENT_DOC) +
 	      strlen((const char *)my_basename(dnnp->fname)) + 1;
 	menupath = g_new(char, len);
 	g_snprintf(menupath, len, "%s%s",
 			MENU_PATH_RECENT_DOC, my_basename(dnnp->fname));
+# endif
 
 # ifdef USE_GNOME
 	gnome_app_remove_menus(GNOME_APP(dnnp->w->toplev), menupath, 1);
@@ -4086,22 +4093,18 @@ menu_recent_doc_add(GtkMenuCallback cbfunc, gpointer data)
 {
 	doc_new_name_t *dnnp = (doc_new_name_t *)data;
 # ifdef USE_GNOME
-	char *path;
-	GnomeUIInfo *menuitem;
+	GnomeUIInfo menuitem[2];
 
-	menuitem = g_new0(GnomeUIInfo, 2);
-	menuitem->type = GNOME_APP_UI_ITEM;
-	menuitem->moreinfo = (gpointer)cbfunc;
-	menuitem->user_data = data;
-	menuitem->label = (char *)g_strdup(my_basename(dnnp->fname));
+	memset(&menuitem, 0, 2 * sizeof(GnomeUIInfo));
+	menuitem[0].type = GNOME_APP_UI_ITEM;
+	menuitem[0].moreinfo = (gpointer)cbfunc;
+	menuitem[0].user_data = data;
+	menuitem[0].label = (char *)g_strdup(my_basename(dnnp->fname));
 	menuitem[1].type = GNOME_APP_UI_ENDOFINFO;
 
-	path = g_strdup(MENU_PATH_RECENT_DOC);
 	gnome_app_insert_menus_with_data(GNOME_APP(dnnp->w->toplev),
-					 path, menuitem, data);
-	g_free(path);
+					 MENU_PATH_RECENT_DOC, menuitem, data);
 	g_free(menuitem->label);
-	g_free(menuitem);
 # else
 	menu_add(dnnp->w->mainfact, MENU_PATH_RECENT_DOC,
 		(char *)my_basename(dnnp->fname), NULL,
@@ -4150,18 +4153,15 @@ quickmenu_init(win_t *w)
  *
  * callback routine invoked when user clicks on right mouse button.
  */
-gboolean
+void
 quickmenu_show(GtkWidget *wgt, GdkEvent *ev)
 {
-	if (ev->type == GDK_BUTTON_PRESS) {
-		GdkEventButton *event = (GdkEventButton *)ev;
-		if (event->button == 3) {
-			gtk_menu_popup(GTK_MENU(wgt), NULL, NULL, NULL, NULL,
-					event->button, event->time);
-			return TRUE;
-		}
-	}
-	return FALSE;
+	GdkEventButton *event = (GdkEventButton *)ev;
+
+	g_assert(ev->type == GDK_BUTTON_PRESS);
+	g_assert(event->button == 3);
+	gtk_menu_popup(GTK_MENU(wgt), NULL, NULL, NULL, NULL,
+		       event->button, event->time);
 } /* quickmenu_show */
 
 
@@ -4204,17 +4204,20 @@ static void
 menu_add(GtkItemFactory *menubar, char *submenupath, char *newmenupath,
 	 char *accelerator, GtkItemFactoryCallback callback, gpointer cbdata)
 {
-	GtkItemFactoryEntry *newentry;
+	GtkItemFactoryEntry newentry;
 	int len;
 
-	newentry = g_new(GtkItemFactoryEntry, 1);
 	len = strlen(submenupath) + strlen(newmenupath) + 1;
-	newentry->path = g_new(char, len);
-	g_snprintf(newentry->path, len, "%s%s", submenupath, newmenupath);
-	newentry->accelerator = accelerator;
-	newentry->callback = callback;
-	newentry->callback_action = 0;
-	newentry->item_type = "<Item>";
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	newentry.path = g_strdup_printf("%s%s", submenupath, newmenupath);
+#else
+	newentry.path = g_new(char, len);
+	g_snprintf(newentry.path, len, "%s%s", submenupath, newmenupath);
+#endif
+	newentry.accelerator = accelerator;
+	newentry.callback = callback;
+	newentry.callback_action = 0;
+	newentry.item_type = "<Item>";
 
 	/*
 	 * again, words cannot express how stupid some of the gtk folks can be.
@@ -4228,14 +4231,13 @@ menu_add(GtkItemFactory *menubar, char *submenupath, char *newmenupath,
 	 * been updated to use the new item factory crap instead of having
 	 * everyone forcibly switch to item factories.  can you say boneheaded?
 	 */
-	gtk_item_factory_create_item(menubar, newentry, cbdata, 2);
+	gtk_item_factory_create_item(menubar, &newentry, cbdata, 2);
 
 	/*
 	 * although it doesn't say that you can anywhere, it looks like we can
 	 * safely free up the space we just allocated
 	 */
-	g_free(newentry->path);
-	g_free(newentry);
+	g_free(newentry.path);
 } /* menu_add */
 # else
 #  ifndef GTK_HAVE_FEATURES_1_1_0
@@ -4243,26 +4245,28 @@ static void
 menu_add(GtkMenuFactory *menubar, char *submenupath, char *newmenupath,
 	 char *accelerator, GtkMenuCallback callback, gpointer cbdata)
 {
-	GtkMenuEntry *newentry;
+	GtkMenuEntry newentry;
 	int len;
 
-	newentry = g_new(GtkMenuEntry, 1);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+	newentry.path = g_strdup_printf("%s%s", submenupath, newmenupath);
+#else
 	len = strlen(submenupath) + strlen(newmenupath) + 1;
-	newentry->path = g_new(char, len);
-	g_snprintf(newentry->path, len, "%s%s", submenupath, newmenupath);
-	newentry->accelerator = accelerator;
-	newentry->callback = callback;
-	newentry->callback_data = cbdata;
-	newentry->widget = NULL;
+	newentry.path = g_new(char, len);
+	g_snprintf(newentry.path, len, "%s%s", submenupath, newmenupath);
+#endif
+	newentry.accelerator = accelerator;
+	newentry.callback = callback;
+	newentry.callback_data = cbdata;
+	newentry.widget = NULL;
 
-	gtk_menu_factory_add_entries(menubar, newentry, 1);
+	gtk_menu_factory_add_entries(menubar, &newentry, 1);
 
 	/*
 	 * although it doesn't say that you can anywhere, it looks like we can
 	 * safely free up the space we just allocated
 	 */
-	g_free(newentry->path);
-	g_free(newentry);
+	g_free(newentry.path);
 } /* menu_add */
 #  endif	/* gtk+-1.0.x */
 # endif	/* !defined(USE_GNOME) && defined(GTK_HAVE_FEATURES_1_1_0) */
