@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: misc.h,v 1.17 2000/02/19 22:57:54 kahn Exp kahn $
+ * $Id: misc.h,v 1.21 2000/03/31 04:40:01 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -45,6 +45,20 @@ extern "C" {
 #define CONNECT_OBJ	(1 << 7)
 #define NO_RELIEF	(1 << 8)
 
+#if defined(USE_GNOME) && defined(USE_LIBGLADE)
+
+# include <glade/glade.h>
+
+# define GLADE_MODAL		(1 << 0)
+# define GLADE_POS_MOUSE	(1 << 1)
+# define GLADE_SHOW		(1 << 2)
+# define GLADE_HIDE		(1 << 3)
+
+extern GtkWidget *my_glade_widget_get(GladeXML *xml, char *name, int flags);
+extern GladeXML *my_glade_xml_get(char *root);
+#endif
+
+extern void gtk_events_flush(void);
 extern char *handle_null_string(char *s);
 extern char *strrepl(char *orig, char *pat, char *repl);
 extern char *my_tempname(void);
@@ -58,9 +72,16 @@ extern char * strcasestr(const char *phaystack, const char *pneedle);
 #ifdef GTK_HAVE_FEATURES_1_1_0
 # define my_basename(name)	g_basename((const gchar *)(name))
 # define my_dirname(name)	g_dirname((const gchar *)(name))
+# define my_path_is_absolute(f)	g_path_is_absolute((const gchar *)(f))
 #else
 extern char *my_basename(const char *name);
 extern char *my_dirname(const char *fname);
+extern bool_t my_path_is_absolute(const char *file_name);
+#endif
+#ifdef USE_GNOME
+# define my_concat_dir_and_file(d, f) g_concat_dir_and_file((d), (f))
+#else
+extern char *my_concat_dir_and_file(const char *dir, const char *file);
 #endif
 
 extern GtkWidget *misc_open_dialog_create(void *w, char *title,
