@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: msgbox.h,v 1.3 1998/10/05 15:33:23 kahn Exp kahn $
+ * $Id: msgbox.h,v 1.5 1999/09/12 14:20:57 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,14 +24,22 @@
 extern "C" {
 #endif /* __cplusplus */
 
-
+#include "main.h"
+#ifdef WANT_MSGBOX
 #include <gtk/gtk.h>
 
 extern void msgbox_init(void);
-extern void msgbox_printf(const char *fmt, ...);
 extern void msgbox_show(GtkWidget *, gpointer data);
 extern void msgbox_close(void);
 
+#else
+
+#define msgbox_init()
+#define msgbox_close()
+
+#endif  /* #ifdef WANT_MSGBOX */
+
+extern void msgbox_printf(const char *fmt, ...);
 
 #ifdef __cplusplus
 }
