@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: prefs.c,v 1.88 2000/04/19 01:27:38 kahn Exp kahn $
+ * $Id: prefs.c,v 1.91 2001/01/01 20:18:09 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -74,6 +74,9 @@ app_prefs_t prefs;
 #define SESSIONRC	"sessionrc"	/* stores files open in last session */
 #define MAX_FONT_LEN	MAXPATH
 #define DEFAULT_FONT	"-adobe-courier-medium-r-normal-*-*-120-*-*-m-*-iso8859-1"
+#ifdef HAVE_SETLOCALE
+#define DEFAULT_FONTSET	"-*-*-medium-r-normal-*-14-*-*-*-*-*-*-*,*"
+#endif
 
 typedef enum {
 	PrefBool,	/* its boolean, but the variable must be a "long" */
@@ -1824,6 +1827,9 @@ prefs_init(void)
 	char *homedir, *buf, *gtkrc;
 	FILE *fp;
 	int num, i, j;
+#ifdef HAVE_SETLOCALE
+	char *lang;
+#endif
 
 	if ((homedir = getenv("HOME")) == NULL) {
 		g_error("$HOME is not set!");
@@ -1923,6 +1929,18 @@ prefs_init(void)
 	prefs.text_hlbg_str  = g_strdup("0 65535 0");	/* blue */
 	prefs.text_font_str  = g_strdup(DEFAULT_FONT);
 	prefs.text_font      = NULL;
+#ifdef HAVE_SETLOCALE
+	lang = setlocale(LC_MESSAGES, "");
+	if (lang) {
+		if (!strncmp(lang, "zh", 2) || !strncmp(lang, "ja", 2) ||
+		    !strncmp(lang, "ko", 2)) {
+			prefs.options1 |= USE_FONTSET;
+			if (prefs.text_font_str)
+				g_free(prefs.text_font_str);
+			prefs.text_font_str = g_strdup(DEFAULT_FONTSET);
+		}
+	}
+#endif
 #ifdef USE_SHELL_INSERT
 	buf = getenv("SHELL");
 	prefs.shell = (buf) ? g_strdup(buf) : g_strdup("/bin/sh");
@@ -2577,38 +2595,46 @@ prefs_glade_wgtopt_list_add(GladeXML *xml)
 	int inum;
 
 	for (pap = app_prefs; pap->name; pap++) {
-		wgt = my_glade_widget_get(xml, pap->name, 0);
-		if (wgt) {
-			if (prefs_glade_handle_special(xml, pap, wgt))
-				continue;
-
-			prefs_wgtopt_list_add(wgt, pap->type, NULL, pap->name);
-			switch (pap->type) {
-			case PrefBool:
-				g_assert(GTK_IS_TOGGLE_BUTTON(wgt));
-				opts = *(long *)(pap->addr);
-				gtk_toggle_button_set_state(
-							GTK_TOGGLE_BUTTON(wgt),
-							(opts & pap->val));
-				break;
-			case PrefString:
-				g_assert(GTK_IS_ENTRY(wgt));
-				if ((s = *(char **)(pap->addr)))
-					gtk_entry_set_text(GTK_ENTRY(wgt), s);
-				break;
-			case PrefInt:
-				g_assert(GTK_IS_SPIN_BUTTON(wgt));
-				inum = *(int *)(pap->addr);
-				gtk_spin_button_set_value(GTK_SPIN_BUTTON(wgt),
-							  (float)inum);
-				break;
-			default:
-				break;
-			}
-		} else {
+		if ((wgt = my_glade_widget_get(xml, pap->name, 0)) == NULL) {
 			GNPDBG_PREFS((
 				"prefs_glade_wgtopt_list_add: '%s' not found\n",
 				pap->name));
+			continue;
+		}
+
+		if (prefs_glade_handle_special(xml, pap, wgt))
+			continue;
+
+		if (GTK_IS_COMBO(wgt)) {
+			prefs_wgtopt_list_add(wgt, ComboType, NULL, pap->name);
+		} else if (GTK_IS_ENTRY(wgt)) {
+			prefs_wgtopt_list_add(wgt, EntryType, NULL, pap->name);
+		} else if (GTK_IS_BUTTON(wgt)) {
+			prefs_wgtopt_list_add(wgt, ButtonType, NULL, pap->name);
+		} else {
+			prefs_wgtopt_list_add(wgt, GenericType, NULL,pap->name);
+		}
+
+		switch (pap->type) {
+		case PrefBool:
+			g_assert(GTK_IS_TOGGLE_BUTTON(wgt));
+			opts = *(long *)(pap->addr);
+			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(wgt),
+						    (opts & pap->val));
+			break;
+		case PrefString:
+			g_assert(GTK_IS_ENTRY(wgt));
+			if ((s = *(char **)(pap->addr)))
+				gtk_entry_set_text(GTK_ENTRY(wgt), s);
+			break;
+		case PrefInt:
+			g_assert(GTK_IS_SPIN_BUTTON(wgt));
+			inum = *(int *)(pap->addr);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(wgt),
+						  (float)inum);
+			break;
+		default:
+			break;
 		}
 	}
 } /* prefs_glade_wgtopt_list_add */
