@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: prefs.h,v 1.39 2000/02/29 03:28:00 kahn Exp kahn $
+ * $Id: prefs.h,v 1.47 2000/04/19 01:29:02 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -47,7 +47,7 @@ extern "C" {
 #define TOOLBAR_RAISED			(1 << 14)
 #define SHOW_HTML_TOOLBAR		(1 << 15)
 #define SHOW_SPLASH			(1 << 16)
-#define DO_FORK				(1 << 17)
+#define ENABLE_SESSION			(1 << 17)
 #define DO_BACKUP			(1 << 18)
 #define DOC_TABS_TOP			(1 << 19)
 #define DOC_TABS_BOTTOM			(1 << 20)
@@ -57,6 +57,9 @@ extern "C" {
 #define USE_FONTSET			(1 << 24)
 #define HTML_TAG_LOWER			(1 << 25)
 #define HTML_TAG_UPPER			(1 << 26)
+#define USE_GTK_THEME_FONTS		(1 << 27)
+#define USER_NAME_IN_TITLE		(1 << 28)
+#define HOST_NAME_IN_TITLE		(1 << 29)
 
 #define DEFAULT_OPTIONS 		(AUTO_INDENT      | SHOW_TABS     | \
 					 SHOW_MSGBAR      | SHOW_TOOLBAR  | \
@@ -64,7 +67,8 @@ extern "C" {
 					 SAVE_WIN_HEIGHT  | USE_MSGBOX | \
 					 SHOW_SPLASH      | SHOW_PRJBAR | \
 					 DO_BACKUP        | DOC_TABS_TOP | \
-					 SHOW_HTML_TOOLBAR| HTML_TAG_UPPER)
+					 SHOW_HTML_TOOLBAR| HTML_TAG_UPPER | \
+					 SAVE_WIN_WIDTH   | SAVE_WIN_HEIGHT)
 
 /* these macros operate on the global variable 'options' */
 #define IS_AUTO_INDENT()		(prefs.options1 & AUTO_INDENT)
@@ -84,7 +88,7 @@ extern "C" {
 #define IS_TOOLBAR_RAISED()		(prefs.options1 & TOOLBAR_RAISED)
 #define IS_SHOW_HTML_TOOLBAR()		(prefs.options1 & SHOW_HTML_TOOLBAR)
 #define IS_SHOW_SPLASH()		(prefs.options1 & SHOW_SPLASH)
-#define IS_DO_FORK()			(prefs.options1 & DO_FORK)
+#define IS_ENABLE_SESSION()		(prefs.options1 & ENABLE_SESSION)
 #define IS_DO_BACKUP()			(prefs.options1 & DO_BACKUP)
 #define IS_DOC_TABS_TOP()		(prefs.options1 & DOC_TABS_TOP)
 #define IS_DOC_TABS_BOTTOM()		(prefs.options1 & DOC_TABS_BOTTOM)
@@ -94,6 +98,9 @@ extern "C" {
 #define IS_USE_FONTSET()		(prefs.options1 & USE_FONTSET)
 #define IS_HTML_TAG_LOWER()		(prefs.options1 & HTML_TAG_LOWER)
 #define IS_HTML_TAG_UPPER()		(prefs.options1 & HTML_TAG_UPPER)
+#define IS_USE_GTK_THEME_FONTS()	(prefs.options1 & USE_GTK_THEME_FONTS)
+#define IS_USER_NAME_IN_TITLE()		(prefs.options1 & USER_NAME_IN_TITLE)
+#define IS_HOST_NAME_IN_TITLE()		(prefs.options1 & HOST_NAME_IN_TITLE)
 
 #define SET_SHOW_TABS()			(prefs.options1 |= SHOW_TABS)
 #define SET_SHOW_MSGBAR()		(prefs.options1 |= SHOW_MSGBAR)
@@ -478,6 +485,10 @@ typedef struct {
 
 	/* non user configurable */
 	char *		appdir;		/* $HOME/PREFS_DIR/ */
+	char *		gladerc;	/* $(DATADIR)/gnotepad+.glade */
+#ifdef WANT_SESSION
+	char *		sessionrc;	/* files open when saving session */
+#endif
 
 	/* appearance settings (most are bit-flag settings) */
 	GtkPositionType	tabpos;		/* doc tab position */
@@ -491,6 +502,9 @@ typedef struct {
 #ifdef USE_RECENT
 	ubyte		maxrecent;	/* max num of recently opened docs */
 #endif	/* USE_RECENT */
+#if defined(USE_UNDOREDO) && defined(GTK_HAVE_FEATURES_1_1_0)
+	int		maxundo;	/* max undo.  -1 is unlimited */
+#endif
 	char *		backupdir;	/* backup directory (default = ./) */
 	char *		backupsuffix;	/* backup file's suffix (def = ~) */
 
@@ -548,8 +562,7 @@ typedef struct {
 extern app_prefs_t prefs;
 
 
-extern void	prefs_init_pre(void);
-extern void	prefs_init_post(void);
+extern void	prefs_init(void);
 extern void	prefs_save(void);
 extern void	prefs_cb(GtkWidget *wgt, gpointer cbdata);
 extern bool_t	prefs_bool_by_name(char *prefname);
