@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: project.h,v 1.5 1999/01/18 20:06:56 kahn Exp kahn $
+ * $Id: project.h,v 1.8 1999/12/10 18:07:07 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -36,12 +36,25 @@ typedef struct {
 	unsigned	numfiles;	/* number of files in project */
 	unsigned	version;	/* project version number */
 	char *		path;		/* path to project */
+	GSList *	files;		/* files in project */
 } prj_t;
 
+#define prj_current(d)	(prj_t *)((d)->prj)
 
 extern void prj_close_cb(GtkWidget *wgt, gpointer cbdata);
 extern void prj_open_cb(GtkWidget *wgt, gpointer cbdata);
-extern void prj_open(GtkWidget *wgt, gpointer cbdata);
+extern void prj_close_all_cb(GtkWidget *wgt, gpointer cbdata);
+extern void prj_list_show(GtkWidget *wgt, gpointer cbdata);
+extern void prj_free_all(win_t *w);
+
+#else
+
+#define prj_current(d)
+#define prj_close_cb(wgt, cbd)
+#define prj_open_cb(wgt, cbd)
+#define prj_close_all_cb(wgt, cbd)
+#define prj_list_show(wgt, cbd)
+#define prj_free_all(w)
 
 #endif	/* WANT_PROJECT */
 
