@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: recent.h,v 1.3 1998/10/05 15:34:53 kahn Exp kahn $
+ * $Id: recent.h,v 1.6 1999/12/10 18:07:44 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,13 +24,23 @@
 extern "C" {
 #endif /* __cplusplus */
 
-
+#include "main.h"
+#ifdef USE_RECENT
 #include "win.h"
 
 extern void	recent_list_add(win_t *w, char *fname);
 extern void	recent_list_init(win_t *w);
 extern void	recent_list_write(win_t *w);
+extern void	recent_list_free(win_t *w);
 
+#else
+
+#define recent_list_add(w, f)
+#define recent_list_init(w)
+#define recent_list_write(w)
+#define recent_list_free(w)
+
+#endif	/* USE_RECENT */
 
 #ifdef __cplusplus
 }
