@@ -1,5 +1,5 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: search.c,v 1.30 2000/02/21 06:52:35 kahn Exp kahn $
+ * $Id: search.c,v 1.34 2000/05/01 16:01:17 kahn Exp kahn $
  *
  * Copyright (C) 1998 Andy C. Kahn
  *
@@ -38,7 +38,9 @@
 /*** local function prototypes ***/
 static void search_line_by_point(doc_t *d, int point);
 static void search_line_execute(GtkWidget *wgt, gpointer cbdata);
+#ifndef USE_LIBGLADE
 static void replace_widgets_create(win_t *w);
+#endif
 static void search_dialog_create(win_t *w, srg_action_t action);
 static void search_dialog_destroy(GtkWidget *wgt, gpointer cbdata);
 static bool_t search_execute(GtkWidget *wgt, gpointer cbdata);
@@ -50,7 +52,6 @@ static void replace_all_cb(GtkWidget *wgt, gpointer cbdata);
 
 
 /*** global function definitions ***/
-#if !defined(GTK_HAVE_FEATURES_1_1_0) || defined(USE_GNOME)
 /*
  * PUBLIC: search_search_cb
  *
@@ -63,6 +64,7 @@ search_search_cb(GtkWidget *wgt, gpointer cbdata)
 } /* search_search_cb */
 
 
+#if !defined(GTK_HAVE_FEATURES_1_1_0) || defined(USE_GNOME)
 /*
  * PUBLIC: goto_line_cb
  *
@@ -111,7 +113,6 @@ search_cb(GtkWidget *wgt, gpointer cbdata, guint cbaction)
 			(void)misc_show_and_raise(sp->toplev);
 		} else if (sp->action != action) {
 			gtk_widget_destroy(sp->toplev);
-			g_free(sp);
 			search_dialog_create(w, action);
 		}
 	} else
@@ -142,6 +143,7 @@ search_again_cb(GtkWidget *wgt, gpointer cbdata)
 
 
 /*** local function definitions ***/
+#ifndef USE_LIBGLADE
 /*
  * PRIVATE: replace_widgets_create
  *
@@ -166,9 +168,8 @@ replace_widgets_create(win_t *w)
 	gtk_box_pack_start(GTK_BOX(hbox), tmp, FALSE, FALSE, 2);
 	w->srg->rtxt_wgt = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(hbox), w->srg->rtxt_wgt, TRUE, TRUE, 2);
-	(void)gtk_signal_connect(GTK_OBJECT(w->srg->rtxt_wgt), "changed",
-				 GTK_SIGNAL_FUNC(search_entries_changed_cb), w);
 } /* replace_widgets_create */
+#endif
 
 
 /*
@@ -187,7 +188,8 @@ search_line_execute(GtkWidget *wgt, gpointer cbdata)
 	search_t *sp;
 
 	sp = w->srg;
-	linenum = atoi(gtk_entry_get_text(GTK_ENTRY(sp->stxt_wgt)));
+	buf = gtk_entry_get_text(GTK_ENTRY(sp->stxt_wgt));
+	linenum = atoi(buf);
 
 	GNPDBG_SEARCH(("search_line_execute: linenum = %d\n", linenum));
 	if (linenum < 1)
@@ -274,12 +276,81 @@ search_line_by_point(doc_t *d, int point)
 static void
 search_dialog_create(win_t *w, srg_action_t action)
 {
-	GtkWidget *tmp, *vbox, *hbox;
+#ifdef USE_LIBGLADE
+	GladeXML *xml;
+#else
+	GtkWidget *vbox, *hbox;
+#endif
+	GtkWidget *tmp;
 	search_t *sp;
 
+	g_assert(action > NoSearch1 && action < NoSearch2);
+
 	sp = g_new0(search_t, 1);
 	w->srg = sp;
 
+#ifdef USE_LIBGLADE
+	if (action == Find) {
+		xml = my_glade_xml_get("Search");
+		g_assert(xml);
+		sp->toplev = my_glade_widget_get(xml, "Search",
+						 GLADE_POS_MOUSE);
+	} else if (action == Replace) {
+		xml = my_glade_xml_get("Search and Replace");
+		g_assert(xml);
+		sp->toplev = my_glade_widget_get(xml, "Search and Replace",
+						 GLADE_POS_MOUSE);
+	} else {
+		g_assert(action == GotoLine);
+		xml = my_glade_xml_get("Goto Line");
+		g_assert(xml);
+		sp->toplev = my_glade_widget_get(xml, "Goto Line",
+						 GLADE_POS_MOUSE);
+	}
+	g_assert(sp->toplev);
+
+	sp->stxt_wgt = my_glade_widget_get(xml, "searchtext", 0);
+	g_assert(sp->stxt_wgt);
+
+	if (action == Find || action == Replace) {
+		sp->startcur = my_glade_widget_get(xml, "startcur", 0);
+		g_assert(sp->startcur);
+		sp->startbeg = my_glade_widget_get(xml, "startbeg", 0);
+		g_assert(sp->startbeg);
+		sp->casesens = my_glade_widget_get(xml, "casesens", 0);
+		g_assert(sp->casesens);
+		sp->regexp = my_glade_widget_get(xml, "regexp", 0);
+		g_assert(sp->regexp);
+	}
+
+	sp->find = my_glade_widget_get(xml, "findbutton", 0);
+	g_assert(sp->find);
+	(void)gtk_signal_connect(GTK_OBJECT(sp->find), "clicked",
+				 (action == GotoLine) ?
+					GTK_SIGNAL_FUNC(search_line_execute) :
+					GTK_SIGNAL_FUNC(search_execute), w);
+
+	if (action == Replace) {
+		sp->rtxt_wgt = my_glade_widget_get(xml, "replacetext", 0);
+		g_assert(sp->rtxt_wgt);
+
+		sp->repl = my_glade_widget_get(xml, "replacebutton", 0);
+		g_assert(sp->repl);
+		(void)gtk_signal_connect(GTK_OBJECT(sp->repl), "clicked",
+					 GTK_SIGNAL_FUNC(replace_execute), w);
+
+		sp->replall = my_glade_widget_get(xml, "replaceallbutton", 0);
+		g_assert(sp->replall);
+		(void)gtk_signal_connect(GTK_OBJECT(sp->replall), "clicked",
+					 GTK_SIGNAL_FUNC(replace_all_cb), w);
+	}
+
+	tmp = my_glade_widget_get(xml, "cancelbutton", 0);
+	g_assert(tmp);
+	(void)gtk_signal_connect(GTK_OBJECT(tmp), "clicked",
+				 GTK_SIGNAL_FUNC(search_dialog_cancel), sp);
+	gtk_object_destroy(GTK_OBJECT(xml));
+#else
 	/* top level dialog window */
 	sp->toplev = gtk_dialog_new();
 	gtk_window_set_policy(GTK_WINDOW(sp->toplev), TRUE, TRUE, TRUE);
@@ -290,8 +361,6 @@ search_dialog_create(win_t *w, srg_action_t action)
 				     _("Search and Replace Text"));
 	else if (action == GotoLine)
 		gtk_window_set_title(GTK_WINDOW(sp->toplev), _("Goto Line #"));
-	(void)gtk_signal_connect(GTK_OBJECT(sp->toplev), "destroy",
-				 GTK_SIGNAL_FUNC(search_dialog_destroy), w);
 
 	vbox = GTK_DIALOG(sp->toplev)->vbox;
 
@@ -312,8 +381,6 @@ search_dialog_create(win_t *w, srg_action_t action)
 	gtk_box_pack_start(GTK_BOX(hbox), tmp, FALSE, FALSE, 2);
 	sp->stxt_wgt = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(hbox), sp->stxt_wgt, TRUE, TRUE, 2);
-	(void)gtk_signal_connect(GTK_OBJECT(sp->stxt_wgt), "changed",
-				 GTK_SIGNAL_FUNC(search_entries_changed_cb), w);
 
 	if (action != GotoLine) {
 		/* create a couple radio buttons for starting search position */
@@ -377,12 +444,22 @@ search_dialog_create(win_t *w, srg_action_t action)
 	tmp = misc_button_new_w_label(_(BUTTON_CANCEL),
 				      GNOME_STOCK_BUTTON_CANCEL,
 				      GTK_SIGNAL_FUNC(search_dialog_cancel),
-				      (gpointer)w,
+				      (gpointer)sp,
 				      GTK_DIALOG(sp->toplev)->action_area,
 				      PACK_START | PACK_EXPAND | PACK_FILL |
 				      CANCEL_DEFAULT, 0);
 
 	gtk_widget_show_all(sp->toplev);
+#endif	/* USE_LIBGLADE */
+
+	(void)gtk_signal_connect(GTK_OBJECT(sp->toplev), "destroy",
+				 GTK_SIGNAL_FUNC(search_dialog_destroy), w);
+	(void)gtk_signal_connect(GTK_OBJECT(sp->toplev), "delete_event",
+				 GTK_SIGNAL_FUNC(gtk_false), NULL);
+	(void)gtk_signal_connect(GTK_OBJECT(sp->stxt_wgt), "changed",
+				 GTK_SIGNAL_FUNC(search_entries_changed_cb),
+				 sp);
+	sp->action = action;
 } /* search_dialog_create */
 
 
@@ -394,9 +471,10 @@ search_dialog_create(win_t *w, srg_action_t action)
 static void
 search_dialog_cancel(GtkWidget *entry, gpointer cbdata)
 {
-	win_t *w = (win_t *)cbdata;
+	search_t *sp = (search_t *)cbdata;
 
-	gtk_widget_hide(w->srg->toplev);
+	sp->repl_cnt = 0;
+	gtk_widget_hide(sp->toplev);
 } /* search_entries_cancel */
 
 
@@ -409,22 +487,28 @@ search_dialog_cancel(GtkWidget *entry, gpointer cbdata)
 static void
 search_entries_changed_cb(GtkWidget *entry, gpointer cbdata)
 {
-	win_t *w = (win_t *)cbdata;
+	search_t *sp = (search_t *)cbdata;
 	bool_t nonempty;
 	char *txt;
 
+	g_assert(sp->action > NoSearch1 && sp->action < NoSearch2);
 	txt = gtk_entry_get_text(GTK_ENTRY(entry));
 	if (!txt)
 		return;	/* shouldn't happen */
 
-	nonempty = (strlen(txt) != 0);
+	if (sp->action == Find || sp->action == Replace)
+		nonempty = (strlen(txt) > 0);
+	else
+		nonempty = (atoi(txt) > 0);
 
-	if (entry == w->srg->stxt_wgt)
-		gtk_widget_set_sensitive(w->srg->find, (gboolean)nonempty);
-
-	if (entry == w->srg->rtxt_wgt) {
-		gtk_widget_set_sensitive(w->srg->repl, (gboolean)nonempty);
-		gtk_widget_set_sensitive(w->srg->replall, (gboolean)nonempty);
+	if (entry == sp->stxt_wgt) {
+		gtk_widget_set_sensitive(sp->find, (gboolean)nonempty);
+		if (sp->repl)
+			gtk_widget_set_sensitive(sp->repl,
+						 (gboolean)nonempty);
+		if (sp->replall)
+			gtk_widget_set_sensitive(sp->replall,
+						 (gboolean)nonempty);
 	}
 } /* search_entries_changed_cb */
 
@@ -439,9 +523,7 @@ search_dialog_destroy(GtkWidget *wgt, gpointer cbdata)
 {
 	win_t *w = (win_t *)cbdata;
 
-	if (GTK_WIDGET_VISIBLE(w->srg->toplev))
-		gtk_widget_destroy(w->srg->toplev);
-
+#if 0
 	w->srg->toplev = NULL;
 	w->srg->stxt_wgt = NULL;
 	w->srg->rtxt_wgt = NULL;
@@ -451,6 +533,9 @@ search_dialog_destroy(GtkWidget *wgt, gpointer cbdata)
 	w->srg->stxt = NULL;
 	w->srg->rtxt = NULL;
 	w->srg->found = FALSE;
+#endif
+	g_free(w->srg);
+	w->srg = NULL;
 } /* search_dialog_destroy */
 
 
@@ -571,15 +656,30 @@ search_execute(GtkWidget *wgt, gpointer cbdata)
 
 	/* no match found */
 	if (!match) {
-		int len;
 		char *msg;
 
 		sp->found = FALSE;
-
-		len = strlen(sp->stxt) + 37;
-		msg = g_new(char, len);
-
-		sprintf(msg, " No more matches for '%s' ", sp->stxt);
+#ifdef GTK_HAVE_FEATURES_1_1_0
+		if (sp->repl && GTK_IS_WIDGET(sp->repl))
+			msg = g_strdup_printf(" No more matches for '%s' \n"
+					      " (%d replacements) ",
+					      sp->stxt, sp->repl_cnt);
+		else
+			msg = g_strdup_printf(" No more matches for '%s' ",
+					      sp->stxt);
+#else
+		if (sp->repl && GTK_IS_WIDGET(sp->repl)) {
+			int len = strlen(sp->stxt) + 128;
+			msg = g_new(char, len);
+			sprintf(msg, " No more matches for '%s' \n"
+				     " (%d replacements) ",
+				sp->stxt, sp->repl_cnt);
+		} else {
+			int len = strlen(sp->stxt) + 37;
+			msg = g_new(char, len);
+			sprintf(msg, " No more matches for '%s' ", sp->stxt);
+		}
+#endif
 		(void)do_dialog_ok( "No more matches", msg);
 		g_free(msg);
 		g_free(searchbuf);
@@ -619,10 +719,10 @@ search_execute(GtkWidget *wgt, gpointer cbdata)
 static void
 replace_all_cb(GtkWidget *wgt, gpointer cbdata)
 {
-	search_t *sp = NULL;
 	bool_t changed = FALSE;
 	bool_t first = TRUE;
 	win_t *w = (win_t *)cbdata;
+	search_t *sp = w->srg;
 
 	while (search_execute(NULL, cbdata)) {
 		replace_execute(NULL, cbdata);
@@ -635,7 +735,6 @@ replace_all_cb(GtkWidget *wgt, gpointer cbdata)
 		 */
 		if (first) {
 			first = FALSE;
-			sp = w->srg;
 			if (GTK_TOGGLE_BUTTON(sp->startbeg)->active) {
 				GTK_TOGGLE_BUTTON(sp->startbeg)->active = FALSE;
 				GTK_TOGGLE_BUTTON(sp->startcur)->active = TRUE;
@@ -700,6 +799,7 @@ replace_execute(GtkWidget *wgt, gpointer cbdata)
 	gtk_text_thaw(GTK_TEXT(d->data));
 
 	sp->found = FALSE;
+	sp->repl_cnt++;
 	gtk_signal_emit_by_name(GTK_OBJECT(d->data), "changed");
 } /* replace_execute */
 
