@@ -1,7 +1,7 @@
 /* vi:set ts=8 sts=0 sw=8:
- * $Id: toolbar.h,v 1.9 1999/01/18 20:08:09 kahn Exp kahn $
+ * $Id: toolbar.h,v 1.17 2000/02/28 17:23:55 kahn Exp kahn $
  *
- * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
+ * Copyright (C) 1998 Andy C. Kahn
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,8 @@
 extern "C" {
 #endif /* __cplusplus */
 
-
+#include "main.h"
+#ifdef USE_TOOLBARS
 #include <gtk/gtk.h>
 #include "win.h"
 
@@ -35,23 +36,40 @@ typedef struct {
 	char *icon;
 	GtkSignalFunc callback;
 	gpointer cbdata;
+	char *prefname;		/* prefs name corresp to this toolbar item */
 } toolbar_data_t;
 
+typedef struct tblist_s {
+	char *name;
+	char *private_name;
+	toolbar_data_t *tbdata;
+	GtkWidget *tb;
+} tblist_data_t;
+
+
+/*** function prototypes ***/
 extern void tb_pic_only(GtkWidget *w, gpointer cbdata);
 extern void tb_pic_text(GtkWidget *w, gpointer cbdata);
 extern void tb_redraw(void *);
 extern void tb_text_only(GtkWidget *w, gpointer cbdata);
 extern void tb_toggle(GtkWidget *w, gpointer cbdata);
-#ifdef APP_GNP
+#if defined(APP_GNP) && defined(USE_HTMLTAGS)
 extern void tb_html_toggle(GtkWidget *wgt, gpointer cbdata);
 #endif
 extern void tb_ttip_toggle(GtkWidget *w, gpointer cbdata);
 extern void toolbar_create(win_t *w, GtkWidget *parent, toolbar_data_t tbdata[],
-			   GtkWidget **tb, GtkWidget **tb_h);
+			   char *tbname);
+extern GtkWidget *toolbar_create_start(win_t *w, toolbar_data_t tbdata[]);
+extern GtkWidget *toolbar_create_finish(win_t *, GtkWidget *, GtkWidget *,
+					char *);
 #ifdef GTK_HAVE_FEATURES_1_1_0
 extern void tb_raised_toggle(GtkWidget *wgt, gpointer cbdata);
 #endif
+extern void tb_item_enable(GtkWidget *tb, char *itemname, bool_t enable);
 
+#else
+# define toolbar_create(w, p, tbd, tbn)
+#endif	/* USE_TOOLBARS */
 
 #ifdef __cplusplus
 }
